@@ -3,7 +3,6 @@ import torch.backends.cudnn as cudnn
 import torch.nn as nn
 import torch.nn.functional as F
 import torchvision.models as models
-import yaml
 import math
 from .utils import make_divisible, check_anchor_order, initialize_weights, model_info, scale_img
 
@@ -48,14 +47,9 @@ class Detect(nn.Module):
 
 
 class Model(nn.Module):
-    def __init__(self, model_cfg='yolov5x.yaml', ch=3, nc=None):  # model, input channels, number of classes
+    def __init__(self, model_name='yolov5x', ch=3, nc=None):  # model, input channels, number of classes
         super(Model, self).__init__()
-        if type(model_cfg) is dict:
-            self.md = model_cfg  # model dict
-        else:  # is *.yaml
-            with open(model_cfg) as f:
-                self.md = yaml.load(f, Loader=yaml.FullLoader)  # model dict
-
+        self.md = get_model_dict(model_name=model_name,nc=nc)
         # Define model
         if nc:
             self.md['nc'] = nc  # override yaml value
@@ -149,6 +143,24 @@ class Model(nn.Module):
                 m.forward = m.fuseforward  # update forward
         model_info(self)
 
+def get_model_dict(model_name='yolov5x',nc=80):
+    if model_name=='yolov5x':
+        model_dict = {'nc': nc, 'depth_multiple': 1.33, 'width_multiple': 1.25, 
+            'anchors': [[116, 90, 156, 198, 373, 326], [30, 61, 62, 45, 59, 119], [10, 13, 16, 30, 33, 23]], 
+            'backbone': [[-1, 1, 'Focus', [64, 3]], [-1, 1, 'Conv', [128, 3, 2]], [-1, 3, 
+            'BottleneckCSP', [128]], [-1, 1, 'Conv', [256, 3, 2]], [-1, 9, 'BottleneckCSP', [256]], [-1, 1, 
+            'Conv', [512, 3, 2]], [-1, 9, 'BottleneckCSP', [512]], [-1, 1, 'Conv', [1024, 3, 2]], [-1, 1, 
+            'SPP', [1024, [5, 9, 13]]]], 'head': [[-1, 3, 'BottleneckCSP', [1024, False]], [-1, 1, 
+            'Conv', [512, 1, 1]], [-1, 1, 'nn.Upsample', ['None', 2, 'nearest']], [[-1, 6], 1, 
+            'Concat', [1]], [-1, 3, 'BottleneckCSP', [512, False]], [-1, 1, 'Conv', [256, 1, 1]], [-1, 1, 
+            'nn.Upsample', ['None', 2, 'nearest']], [[-1, 4], 1, 'Concat', [1]], [-1, 3, 
+            'BottleneckCSP', [256, False]], [-1, 1, 'nn.Conv2d', ['na * (nc + 5)', 1, 1]], [-2, 1, 
+            'Conv', [256, 3, 2]], [[-1, 14], 1, 'Concat', [1]], [-1, 3, 
+            'BottleneckCSP', [512, False]], [-1, 1, 'nn.Conv2d', ['na * (nc + 5)', 1, 1]], [-2, 1, 
+            'Conv', [512, 3, 2]], [[-1, 10], 1, 'Concat', [1]], [-1, 3, 
+            'BottleneckCSP', [1024, False]], [-1, 1, 'nn.Conv2d', ['na * (nc + 5)', 1, 1]], [[], 1, 
+            'Detect', ['nc', 'anchors']]]}
+    return model_dict
 
 def parse_model(md, ch):  # model_dict, input_channels(3)
     print('\n%3s%15s%3s%10s  %-40s%-30s' % ('', 'from', 'n', 'params', 'module', 'arguments'))
